/* eslint-disable @next/next/no-img-element */
import { capitalizeFirstLetter } from "@/app/common/string-utils";
import { SkinPart } from "mcutils-library";
import Link from "next/link";
import { ReactElement } from "react";
import { Button } from "../ui/button";
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogFooter,
  DialogHeader,
  DialogTitle,
  DialogTrigger,
} from "../ui/dialog";
import { Tooltip, TooltipContent, TooltipTrigger } from "../ui/tooltip";

type SkinPartImageProps = {
  /**
   * The player's name.
   */
  playerName: string;

  /**
   * The skin part.
   */
  part: SkinPart;

  /**
   * The URL to the skin part.
   */
  url: string;

  /**
   * The size to display the skin part.
   */
  size?: number;
};

type SkinOverlay = {
  /**
   * The title to display.
   */
  title: string;

  /**
   * Whether to show the part with overlays.
   */
  overlays?: boolean;
};

const skinPartOverlay: SkinOverlay[] = [
  {
    title: "Without Overlays",
  },
  {
    title: "With Overlays",
    overlays: true,
  },
];

export function SkinPartImage({ playerName, part, url, size = 64 }: SkinPartImageProps): ReactElement {
  const partName = capitalizeFirstLetter(part);

  return (
    <Tooltip>
      <TooltipTrigger>
        <Dialog>
          <DialogTrigger asChild>
            <img
              src={url}
              alt={`The ${playerName}'s ${partName}`}
              loading="lazy"
              style={{
                height: `${size}px`,
              }}
            />
          </DialogTrigger>
          <DialogContent className="w-fit h-fit">
            <DialogHeader>
              <DialogTitle>
                {playerName}&apos;s {partName}
              </DialogTitle>
              <DialogDescription>See the skin part below.</DialogDescription>
            </DialogHeader>
            <div className="flex items-center w-full flex-col divide-y md:flex-row md:divide-x md:divide-y-0 text-muted-foreground">
              {skinPartOverlay.map((overlay, index) => {
                return (
                  <div key={index} className="p-2 w-max text-center items-center font-semibold flex flex-col gap-2">
                    <p>{overlay.title}</p>
                    <img
                      className="h-[200px] md:h-[256px] w-max"
                      src={url + (overlay.overlays ? "?overlays=true" : "")}
                      alt={`The ${playerName}'s ${partName}`}
                      loading="lazy"
                    />
                  </div>
                );
              })}
            </div>
            <DialogFooter>
              <Link href={url} target="_blank">
                <Button>Open in new tab</Button>
              </Link>
            </DialogFooter>
          </DialogContent>
        </Dialog>
      </TooltipTrigger>
      <TooltipContent>
        <p>
          Click to view {playerName}&apos;s {partName}
        </p>
      </TooltipContent>
    </Tooltip>
  );
}
